@@ -138,6 +138,57 @@ firstPassage <- function(object, state, n) {
   return(outMatr)
 }
 
+
+
+
+#' returns first passage probabilities for a set of state given initial state
+#' 
+#' @description The function calculates first passage probability given an initial state
+#' 
+#' @param object a markovchain-class object
+#' @param state intital state of the process (charactervector)
+#' @param set set of states A, first passage of which is to be calculated
+#' @param n Number of rows on which compute the distribution
+#' 
+#' @return A vector of size n showing the first time proability 
+#' @references
+#' Renaldo Feres, Notes for Math 450 Matlab listings for Markov chains;
+#' MIT OCW, course - 6.262, Discrete Stochastic Processes, course-notes, chap -05
+#' 
+#' @author Vandit Jain
+#' 
+#' @seealso \code{\link{firstPassage}}
+#' @examples 
+#' statesNames <- c("a", "b", "c")
+#' markovB <- new("markovchain", states = statesNames, transitionMatrix =
+#' matrix(c(0.2, 0.5, 0.3,
+#'          0, 1, 0,
+#'          0.1, 0.8, 0.1), nrow = 3, byrow = TRUE,
+#'        dimnames = list(statesNames, statesNames)
+#' ))
+#'  
+#' @export 
+firstPassageMultiple <- function(object,state,set, n){
+  P <- object@transitionMatrix
+  stateNames <- states(object)
+  
+  k <- which(stateNames == state)
+  
+  setno <- rep(0,length(set))
+  for(i in 1:length(set))
+  {
+    setno[i] = which(set[i] == stateNames)
+  }
+  
+  outMatr <- .firstPassageMultipleRCpp(P,k,setno,n)
+  colnames(outMatr) <- "set"
+  rownames(outMatr) <- 1:n
+  return(outMatr)
+}
+
+
+
+
 # return a list of communicating classes
 
 #' @name communicatingClasses
@@ -212,24 +263,133 @@ recurrentClasses <- function(object) {
 }
 
 
-#' @title Check if a DTMC is regular
+
+#' @title Calculates committor of a markovchain object with respect to set A, B
 #' 
-#' @description Function to check wether a DTCM is regular
+#' @description Returns the probability of hitting states rom set A before set B 
+#' with different initial states
 #' 
-#' @details A regular Markov chain has $A^n$ strictly positive for some n. 
-#' So we check: if there is only one eigenvector; if the steadystate vector is striclty positive.
+#' @usage committorAB(object,A,B,p)
 #' 
-#' @param object a markovchain object
+#' @param object a markovchain class object
+#' @param A a set of states
+#' @param B a set of states
+#' @param p initial state (default value : 1)
 #' 
-#' @return A boolean value
+#' @details The function solves a system of linear equations to calculate probaility that the process hits
+#' a state from set A before any state from set B
+#' 
+#' @return Return a vector of probabilities in case initial state is not provided else returns a number
 #' 
 #' @examples 
-#' P=matrix(c(0.5,.25,.25,.5,0,.5,.25,.25,.5),nrow = 3)
-#' colnames(P)<-rownames(P)<-c("R","N","S")
-#' ciao<-as(P,"markovchain")
-#' is.regular(ciao)
+#' transMatr <- matrix(c(0,0,0,1,0.5,
+#'                       0.5,0,0,0,0,
+#'                       0.5,0,0,0,0,
+#'                       0,0.2,0.4,0,0,
+#'                       0,0.8,0.6,0,0.5),
+#'                       nrow = 5)
+#' object <- new("markovchain", states=c("a","b","c","d","e"),transitionMatrix=transMatr)
+#' committorAB(object,c(5),c(3))
 #' 
-#' @seealso \code{\link{is.irreducible}}
+#' @export
+committorAB <- function(object,A,B,p=1) {
+  
+  if(!class(object) == "markovchain")
+    stop("please provide a valid markovchain object")
+  
+  matrix <- object@transitionMatrix
+  
+  noofstates <- length(object@states)
+  
+  for(i in length(A))
+  {
+    if(A[i] <= 0 || A[i] > noofstates)
+      stop("please provide a valid set A")
+  }
+  
+  for(i in length(B))
+  {
+    if(B[i] <= 0 || B[i] > noofstates)
+      stop("please provide a valid set B")
+  }
+  
+  for(i in 1:noofstates)
+  {
+    if(i %in% A && i %in% B)
+      stop("intersection of set A and B in not null")
+  }
+  
+  if(p <=0 || p > noofstates)
+    stop("please provide a valid initial state")
+  
+  I <- diag(noofstates)
+  
+  matrix <- matrix - I
+  
+  A_size = length(A)
+  B_size = length(B)
+  
+  for(i in 1:A_size)
+  {
+    for(j in 1:noofstates)
+    {
+      if(A[i]==j)
+        matrix[A[i],j] = 1
+      else
+        matrix[A[i],j] = 0
+    }
+  }
+  
+  for(i in 1:B_size)
+  {
+    for(j in 1:noofstates)
+    {
+      if(B[i]==j)
+        matrix[B[i],j] = 1
+      else
+        matrix[B[i],j] = 0
+    }
+  }
+  
+  b <- rep(0,noofstates)
+  
+  
+  for(i in 1:A_size)
+  {
+    b[A[i]] = 1
+  }
+  
+  out <- solve(matrix,b)
+  
+  if(missing(p))
+    return(out)
+  else
+    return(out[p])
+}
+
+
+
+
+
+
+# @title Check if a DTMC is regular
+# 
+# @description Function to check wether a DTCM is regular
+# 
+# @details A regular Markov chain has $A^n$ strictly positive for some n. 
+# So we check: if there is only one eigenvector; if the steadystate vector is striclty positive.
+# 
+# @param object a markovchain object
+# 
+# @return A boolean value
+# 
+# @examples 
+# P=matrix(c(0.5,.25,.25,.5,0,.5,.25,.25,.5),nrow = 3)
+# colnames(P)<-rownames(P)<-c("R","N","S")
+# ciao<-as(P,"markovchain")
+# is.regular(ciao)
+# 
+# @seealso \code{\link{is.irreducible}}
 
 
 # is.regular<-function(object) {
@@ -237,4 +397,6 @@ recurrentClasses <- function(object) {
 #   minDim<-min(dim(eigenValues))
 #   out <- minDim==1 & all(eigenValues>0)
 #   return(out)
-# }
\ No newline at end of file
+# }
+
+
